
.. _Django: https://www.djangoproject.com/
.. _GitHub: https://github.com/bckohan/django-routines
.. _PyPI: https://pypi.python.org/pypi/django-routines
.. _rich: https://rich.readthedocs.io/
.. _django-routines: https://pypi.python.org/pypi/django-routines
.. _django-typer: https://pypi.python.org/pypi/django-typer
.. _DRY: https://en.wikipedia.org/wiki/Don%27t_repeat_yourself
.. _django-split-settings: https://pypi.org/project/django-split-settings/
